about summary refs log tree commit diff
diff options
context:
space:
mode:
authorRalf Jung <post@ralfj.de>2025-01-31 11:22:56 +0100
committerRalf Jung <post@ralfj.de>2025-01-31 11:22:56 +0100
commit25cdd06b46fb63cd0ad90b76e8fca5804665b04f (patch)
treed5ad89f56e2fe962a65f2587e9b17848e051ad39
parentbcda8927d010915dd50991cda41d01ee16e545ee (diff)
downloadrust-25cdd06b46fb63cd0ad90b76e8fca5804665b04f.tar.gz
rust-25cdd06b46fb63cd0ad90b76e8fca5804665b04f.zip
increase thread limit for many-seeds mode
-rw-r--r--src/tools/miri/src/bin/miri.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tools/miri/src/bin/miri.rs b/src/tools/miri/src/bin/miri.rs
index 988a0be6327..77692ed8655 100644
--- a/src/tools/miri/src/bin/miri.rs
+++ b/src/tools/miri/src/bin/miri.rs
@@ -723,8 +723,8 @@ fn main() {
 
     // Ensure we have parallelism for many-seeds mode.
     if many_seeds.is_some() && !rustc_args.iter().any(|arg| arg.starts_with("-Zthreads=")) {
-        // Clamp to 8 threads; things get a lot less efficient beyond that due to lock contention.
-        let threads = std::thread::available_parallelism().map_or(1, |n| n.get()).min(8);
+        // Clamp to 10 threads; things get a lot less efficient beyond that due to lock contention.
+        let threads = std::thread::available_parallelism().map_or(1, |n| n.get()).min(10);
         rustc_args.push(format!("-Zthreads={threads}"));
     }
     let many_seeds =